!function(){var n=Handlebars.template,l=Handlebars.templates=Handlebars.templates||{};l["button-dismiss"]=n({compiler:[8,">= 4.3.0"],main:function(n,l,t,o,e){var a=null!=l?l:n.nullContext||{},i=n.hooks.helperMissing,c="function",u=n.escapeExpression,s=n.lookupProperty||function(n,l){if(Object.prototype.hasOwnProperty.call(n,l))return n[l]};return'<button id="'+u(typeof(n=null!=(n=s(t,"id")||(null!=l?s(l,"id"):l))?n:i)==c?n.call(a,{name:"id",hash:{},data:e,loc:{start:{line:1,column:12},end:{line:1,column:18}}}):n)+'" class="navigation_button long_button" onclick="document.getElementById(\'close-modal\').click()">\n    <span>'+u(typeof(n=null!=(n=s(t,"label")||(null!=l?s(l,"label"):l))?n:i)==c?n.call(a,{name:"label",hash:{},data:e,loc:{start:{line:2,column:10},end:{line:2,column:19}}}):n)+"</span>\n</button>"},useData:!0}),l["button-redirect"]=n({compiler:[8,">= 4.3.0"],main:function(n,l,t,o,e){var a=null!=l?l:n.nullContext||{},i=n.hooks.helperMissing,c="function",u=n.escapeExpression,s=n.lookupProperty||function(n,l){if(Object.prototype.hasOwnProperty.call(n,l))return n[l]};return'<button id="'+u(typeof(n=null!=(n=s(t,"id")||(null!=l?s(l,"id"):l))?n:i)==c?n.call(a,{name:"id",hash:{},data:e,loc:{start:{line:1,column:12},end:{line:1,column:18}}}):n)+'" class="navigation_button long_button" onclick="window.location.href=\''+u(typeof(n=null!=(n=s(t,"location")||(null!=l?s(l,"location"):l))?n:i)==c?n.call(a,{name:"location",hash:{},data:e,loc:{start:{line:1,column:89},end:{line:1,column:101}}}):n)+"'\">\n    <span>"+u(typeof(n=null!=(n=s(t,"label")||(null!=l?s(l,"label"):l))?n:i)==c?n.call(a,{name:"label",hash:{},data:e,loc:{start:{line:2,column:10},end:{line:2,column:19}}}):n)+"</span>\n</button>"},useData:!0})}();